@@ -58,11 +58,11 @@ class Predictor:
         return df
 
 # Load the model
-path_to_model = pkg_resources.resource_filename('exo_planet', 'assets/num_planets_model.p')
+path_to_model = pkg_resources.resource_filename('exo_predict', 'data/num_planets_model.p')
 model = pkl.load(open(path_to_model, "rb"))
 
 def create_num_planets_predictor():
     """
     This function creates and instance of the class so that the user is not limited to one instance in a single notebook or .py file.
     """
-    return Predictor(model=model)
\ No newline at end of file
+    return Predictor(model=model)
